@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# $Id: SyntaxAndOutput.py,v 1.47 2003/03/25 21:18:34 tavis_rudd Exp $
+# $Id: SyntaxAndOutput.py,v 1.57 2005/05/30 23:26:59 tavis_rudd Exp $
 """Syntax and Output tests.
 
 TODO
@@ -12,12 +12,12 @@ TODO
 Meta-Data
 ================================================================================
 Author: Tavis Rudd <tavis@damnsimple.com>
-Version: $Revision: 1.47 $
+Version: $Revision: 1.57 $
 Start Date: 2001/03/30
-Last Revision Date: $Date: 2003/03/25 21:18:34 $
+Last Revision Date: $Date: 2005/05/30 23:26:59 $
 """
 __author__ = "Tavis Rudd <tavis@damnsimple.com>"
-__revision__ = "$Revision: 1.47 $"[11:-2]
+__revision__ = "$Revision: 1.57 $"[11:-2]
 
 
 ##################################################
@@ -30,6 +30,7 @@ from copy import deepcopy
 import os
 import os.path
 import new
+import warnings
 
 from Cheetah.NameMapper import NotFound
 from Cheetah.NameMapper import C_VERSION as NameMapper_C_VERSION
@@ -112,6 +113,8 @@ defaultTestNameSpace = {
         ],
     'nameList': [('john', 'doe'), ('jane', 'smith')],
     'letterList': ['a', 'b', 'c'],
+    '_': lambda x: 'Translated: ' + x,
+    'unicodeData':u'aoeu12345\u1234',
     }
 
 
@@ -134,14 +137,10 @@ Template output mismatch: %(notes)s
     convertEOLs = True
     DEBUGLEV = 0
     _searchList = [defaultTestNameSpace]
-    _templateSettings = {}
     
     def searchList(self):
         return self._searchList
 
-    def settings(self):
-        return self._templateSettings
-
     def verify(self, input, output):
         self._gen(input)
         self._verify(output)
@@ -150,8 +149,7 @@ Template output mismatch: %(notes)s
     def _gen(self, input):
         self._input = input
         self.template = templateObj = Template(input,
-                                               searchList=self.searchList(),
-                                               settings=self.settings(),
+                                               searchList=self.searchList()
                                                )
         if self.DEBUGLEV == 1:
             print self.genClassCode()
@@ -160,9 +158,10 @@ Template output mismatch: %(notes)s
         
     def _verify(self, expectedOutput, notes=''):
         templateObj = self.template
-        output = str(templateObj)
+        output = templateObj.respond()
+        #print self.genClassCode() #@@ DEBUG
         templateObj.shutdown()
-            
+
         assert output == expectedOutput, self.report \
                % {'notes': notes,
                   'template': self._input,
@@ -184,8 +183,25 @@ class EmptyTemplate(OutputTest):
     convertEOLs = False
     def test1(self):
         """an empty string for the template"""
-        self.verify("",
-                    "")
+        
+        warnings.filterwarnings('error',
+                                'You supplied an empty string for the source!',
+                                UserWarning)
+        try:
+            self.verify("", "")
+        except UserWarning:
+            pass
+        else:
+            self.fail("Should warn about empty source strings.")
+        
+        try:
+            self.verify("#implements foo", "")
+        except NotImplementedError:
+            pass
+        else:
+            self.fail("This should barf about respond() not being implemented.")
+
+        self.verify("#implements respond", "")
 
 class Backslashes(OutputTest):
     convertEOLs = False
@@ -533,11 +549,27 @@ class Placeholders_Vals(OutputTest):
         """
         self.verify("$none", "")
 
-    def test7(self):
+    def test8(self):
         """True, False
         """
-        self.verify("$True $False", "1 0")
+        self.verify("$True $False", "%s %s"%(repr(True), repr(False)))
 
+    def test9(self):
+        """$_
+        """
+        self.verify("$_('foo')", "Translated: foo")
+
+class UnicodeStrings(OutputTest):
+    def test1(self):
+        """unicode data in placeholder
+        """
+        self.verify("$unicodeData", "aoeu12345\xe1\x88\xb4")
+
+    def test2(self):
+        """unicode data in body
+        """
+        self.verify(u"aoeu12345\u1234", u"aoeu12345\u1234")
+        
 class Placeholders_Esc(OutputTest):
     convertEOLs = False
     def test1(self):
@@ -805,15 +837,15 @@ class NameMapper(OutputTest):
                     "110%")
 
 
-class NameMapperDict(OutputTest):
-
-    _searchList = [{"update": "Yabba dabba doo!"}]
-
-    def test1(self):
-        if NameMapper_C_VERSION:
-            return # This feature is not in the C version yet.
-        self.verify("$update", "Yabba dabba doo!")
-
+#class NameMapperDict(OutputTest):
+#
+#    _searchList = [{"update": "Yabba dabba doo!"}]
+#
+#    def test1(self):
+#        if NameMapper_C_VERSION:
+#            return # This feature is not in the C version yet.
+#        self.verify("$update", "Yabba dabba doo!")
+#
 
 class CacheDirective(OutputTest):
     
@@ -1119,6 +1151,14 @@ class AttrDirective(OutputTest):
                     "  --   \nblarg")
 
 
+class EncodingDirective(OutputTest):
+
+    def test1(self):
+        """basic #encoding """
+        self.verify("#encoding utf-8\n1234",
+                    "1234")
+
+
 class DefDirective(OutputTest):
 
     def test1(self):
@@ -1312,6 +1352,18 @@ inner
             "#block $testMeth($arg='This is my block'): $arg",
             "This is my block")
 
+    def test14(self):
+        """single line #block with None for content"""
+        self.verify(
+            """#block $testMeth: $None\ntest $testMeth-""",
+            "test -")
+
+    def test15(self):
+        """single line #block with nothing for content"""
+        self.verify(
+            """#block $testMeth: \ntest $testMeth-""",
+            "test -")
+
 class IncludeDirective(OutputTest):
 
     def setUp(self):
@@ -1559,15 +1611,20 @@ class IfDirective(OutputTest):
                     "1 - 1")
 
     def test14(self):
-        """#if <condition> then <true> else <false> """
+        """single-line #if: simple"""
         self.verify("#if $emptyString then 'true' else 'false'",
                     "false")
 
     def test15(self):
-        """#if <condition> then <true> else <false> """
+        """single-line #if: more complex"""
         self.verify("#if $anInt then 'true' else 'false'",
                     "true")
 
+    def test16(self):
+        """single-line #if: with the words 'else' and 'then' in the output """
+        self.verify("#if ($anInt and not $emptyString==''' else ''') then $str('then') else 'else'",
+                    "then")
+
 class UnlessDirective(OutputTest):
     
     def test1(self):
@@ -1649,7 +1706,7 @@ class ContinueDirective(OutputTest):
 #if $i == 3
   #set $i += 1        
   #continue
-#end try
+#end if
 $i#slurp
 #set $i += 1
 #end while""",
@@ -1660,7 +1717,7 @@ $i#slurp
         self.verify("""#for $i in range(5)
 #if $i == 3
   #continue
-#end try
+#end if
 $i#slurp
 #end for""",
         "0124")
@@ -1672,7 +1729,7 @@ class BreakDirective(OutputTest):
 #while $i < 5
 #if $i == 3
   #break
-#end try
+#end if
 $i#slurp
 #set $i += 1
 #end while""",
@@ -1683,7 +1740,7 @@ $i#slurp
         self.verify("""#for $i in range(5)
 #if $i == 3
   #break
-#end try
+#end if
 $i#slurp
 #end for""",
         "012")
@@ -1861,8 +1918,9 @@ class ImportDirective(OutputTest):
     def test9(self):
         """#import os.path -- use it
         """
+        
         self.verify("#import os.path\n$os.path.exists('.')",
-                    "1")
+                    repr(True))
 
     def test10(self):
         """#import os.path -- use it with NameMapper turned off
@@ -1873,8 +1931,14 @@ useNameMapper=False
 #end compiler-settings
 #import os.path
 $os.path.exists('.')""",
-                    "1")
+                    repr(True))
 
+    def test11(self):
+        """#from math import *
+        """
+        
+        self.verify("#from math import *\n$pow(1,2) $log10(10)",
+                    "1.0 1.0")
 
 class CompilerDirective(OutputTest):
     def test1(self):
@@ -1939,19 +2003,6 @@ $anInt//comment
 
 class ExtendsDirective(OutputTest):
 
-    def setUp(self):
-        fp = open('SampleBaseClass.py','w')
-        fp.write(str(Compiler(source="#extends Cheetah.Templates.SkeletonPage",
-                               moduleName='SampleBaseClass',
-                               mainClassName='SampleBaseClass')))
-        fp.flush()
-        fp.close
-
-    def tearDown(self):
-        for ext in ('py','pyc','pyo'):
-            if os.path.exists('SampleBaseClass.' + ext):
-                os.remove('SampleBaseClass.' + ext)
-
     def test1(self):
         """#extends Cheetah.Templates._SkeletonPage"""
         self.verify("""#from Cheetah.Templates._SkeletonPage import _SkeletonPage
@@ -1978,12 +2029,13 @@ $spacer()
                     '<img src="spacer.gif" width="1" height="1" alt="" />\n')
 
     def test4(self):
-        """#extends SampleBaseClass without #import"""
-        self.verify("""#extends SampleBaseClass
+        """#extends with globals and searchList test"""
+        self.verify("""#extends Cheetah.Templates.SkeletonPage
+#set global g="Hello"
 #implements respond
-$spacer()
+$g $numOne
 """,
-                    '<img src="spacer.gif" width="1" height="1" alt="" />\n')
+                    'Hello 1\n')
 
 class ImportantExampleCases(OutputTest):
     def test1(self):
@@ -2089,19 +2141,19 @@ class VarExists(OutputTest):               # Template.varExists()
         """$varExists('$anInt')
         """
         self.verify("$varExists('$anInt')",
-                    "1")
+                    repr(True))
 
     def test2(self):
         """$varExists('anInt')
         """
         self.verify("$varExists('anInt')",
-                    "1")
+                    repr(True))
 
     def test3(self):
         """$varExists('$anInt')
         """
         self.verify("$varExists('$bogus')",
-                    "0")
+                    repr(False))
 
     def test4(self):
         """$varExists('$anInt') combined with #if false
